import { world, system } from "@minecraft/server";
import { ActionFormData, ModalFormData } from "@minecraft/server-ui";

const MENU_STRUCTURE = {
    main: {
        title: "§lMain Menu",
        body: "Select an option:",
        buttons: [
            {
                text: "§lOption 1\n§rOption Description 1",
                action: "showSubMenu1"
            },
            {
                text: "§l§aOption 2\n§rOption Description 2",
                action: "showSubMenu2"
            },
            {
                text: "§l§eConfiguration\n§rAdjust the options",
                action: "showConfig"
            }
        ]
    },
    subMenu1: {
        title: "§lSubmenu 1",
        body: "Select an option:",
        buttons: [
            {
                text: "§aOption 1.1\nDescription 1.1",
                action: (player) => {
                    player.sendMessage("§aExecuted option 1.1");
                }
            },
            {
                text: "§bOption 1.2\nDescription 1.2",
                action: (player) => {
                    player.sendMessage("§bExecuted option 1.2");
                }
            }
        ]
    }
};

const MODAL_FORM_STRUCTURE = {
    config: {
        title: "§lFormulario de Configuration",
        elements: [
            {
                type: "toggle",
                label: "§aOption 1",
                defaultValue: true
            },
            {
                type: "toggle",
                label: "§bOption 2",
                defaultValue: false
            },
            {
                type: "slider",
                label: "§eValue",
                min: 0,
                max: 100,
                step: 1,
                defaultValue: 50
            },
            {
                type: "textField",
                label: "Name",
                placeholder: "Enter a name..."
            }
        ],
        onSubmit: (player, values) => {
            const [option1, option2, sliderValue, textValue] = values;
            player.sendMessage(`
                §aOpciones seleccionadas:
                - Option 1: ${option1 ? "§aActivated" : "§cDeactivated"}
                - Option 2: ${option2 ? "§aActivated" : "§cDeactivated"}
                - Value: §e${sliderValue}
                - Texto: §f${textValue}
            `);
        }
    },
    settings: {
        title: "§lAdditional Settings",
        elements: [
            {
                type: "toggle",
                label: "§dNight Mode",
                defaultValue: false
            },
            {
                type: "slider",
                label: "§bVolume",
                min: 0,
                max: 100,
                step: 10,
                defaultValue: 70
            }
        ],
        onSubmit: (player, values) => {
            const [darkMode, volume] = values;
            player.sendMessage(`
                §aSettings saved:
                - Night Mode: ${darkMode ? "§aActivated" : "§cDeactivated"}
                - Volume: §b${volume}%
            `);
        }
    }
};

class UIManager {
    constructor() {
        this.menuActions = {
            showSubMenu1: (player) => this.showMenu(player, 'subMenu1'),
            showSubMenu2: (player) => this.showModalForm(player, 'config'),
            showConfig: (player) => this.showModalForm(player, 'settings')
        };
    }

    showMenu(player, menuType = 'main') {
        const menuData = MENU_STRUCTURE[menuType];
        const form = new ActionFormData()
            .title(menuData.title)
            .body(menuData.body);

        menuData.buttons.forEach(button => {
            form.button(button.text);
        });

        system.run(() => {
            form.show(player).then((response) => {
                if (!response || response.canceled) return;

                const selectedButton = menuData.buttons[response.selection];
                if (typeof selectedButton.action === 'string') {
                    const actionFunction = this.menuActions[selectedButton.action];
                    if (actionFunction) actionFunction(player);
                } else if (typeof selectedButton.action === 'function') {
                    selectedButton.action(player);
                }
            });
        });
    }

    showModalForm(player, formType) {
        const formData = MODAL_FORM_STRUCTURE[formType];
        const form = new ModalFormData()
            .title(formData.title);

        formData.elements.forEach(element => {
            switch(element.type) {
                case "toggle":
                    form.toggle(element.label, element.defaultValue);
                    break;
                case "slider":
                    form.slider(element.label, element.min, element.max, element.step, element.defaultValue);
                    break;
                case "textField":
                    form.textField(element.label, element.placeholder);
                    break;
            }
        });

        system.run(() => {
            form.show(player).then(response => {
                if (!response.canceled) {
                    formData.onSubmit(player, response.formValues);
                }
            });
        });
    }

    showConfigMenu(player) {
        const form = new ActionFormData()
            .title("§l§eConfiguration")
            .body("Select what you want to configure:")
            .button("§3Configuration Option 1\nDescription of the configuration")
            .button("§bConfiguration Option 2\nDescription of the configuration");

        system.run(() => {
            form.show(player).then((response) => {
                if (!response || response.canceled) return;

                switch(response.selection) {
                    case 0:
                        player.sendMessage("§aYou selected the configuration 1");
                        break;
                    case 1:
                        player.sendMessage("§bYou selected the configuration 2");
                        break;
                }
            });
        });
    }
}

const uiManager = new UIManager();

world.beforeEvents.itemUse.subscribe((eventData) => {
    const player = eventData.source;
    const item = eventData.itemStack;
    
    if (item?.typeId === "minecraft:stick") {
        uiManager.showMenu(player);
    }
});